Package: dslabs
Title: Data Science Labs
Version: 0.9.1
Description: Datasets and functions that can be used for data analysis practice, homework and projects in data science courses and workshops. 26 datasets are available for case studies in data visualization, statistical inference, modeling, linear regression, data wrangling and machine learning.
Authors@R: 
  c(person(given = c("Rafael", "A."), 
           family = "Irizarry", 
           role = c("aut", "cre"), 
           email = "rafael_irizarry@dfci.harvard.edu"),
    person(given = "Amy",
           family = "Gill",
           role = "aut"))
Depends: R (>= 4.1.0)
Imports: ggplot2
License: Artistic-2.0
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2025-12-01 19:56:57 UTC; rafa
Author: Rafael A. Irizarry [aut, cre],
  Amy Gill [aut]
Maintainer: Rafael A. Irizarry <rafael_irizarry@dfci.harvard.edu>
Repository: CRAN
Date/Publication: 2025-12-02 06:10:32 UTC
Built: R 4.6.0; ; 2026-04-28 01:29:30 UTC; unix
