# Generated by roxygen2: do not edit by hand

export(ds_theme_set)
export(fit_recommender_model)
export(read_mnist)
export(rfalling_object)
export(take_poll)
importFrom(stats,rnorm)
importFrom(stats,rt)
importFrom(utils,download.file)
