#' Italian olive
#' 
#' Composition in percentage of eight fatty acids found in the lipid fraction of 572 Italian olive oils
#' 
#' \itemize{
#' \item region. General region of Italy.
#' \item area. Area of Italy. 
#' \item palmitic. Percent palmitic acid of sample. 
#' \item palmitoleic. Percent palmitoleic of sample. 
#' \item stearic. Percent stearic acid of sample.  
#' \item oleic. Percent oleic acid of sample.  
#' \item linoleic. Percent linoleic acid of sample.  
#' \item linolenic. Percent linolenic acid of sample.  
#' \item arachidic. Percent arachidic acid of sample.  
#' \item eicosenoic. Percent eicosenoic acid of sample.  
#' }
#'
#' @docType data
#'
#' @usage data(olive)
#'
#' @format An object of class \code{"data.frame"}. 
#'
#' @keywords datasets
#'
#'
#' @source J. Zupan, and J. Gasteiger.  Neural Networks in Chemistry and Drug Design.
#' 
#' @examples
#' data(olive)
#' head(olive)
"olive"
