#' Gender bias among graduate school admissions to UC Berkeley.
#' 
#' The admission data for six majors for the fall of 1973; often used as an example of Simpson's paradox
#'
#'
#' \itemize{
#'   \item major. The major or university department.
#'   \item gender. Men or women.
#'   \item admitted. Percent of students admitted.
#'   \item applicants. Total number of applicants.
#' }
#' 
#' @docType data
#'
#' @usage data(admissions)
#'
#' @format An object of class \code{"data.frame"}. 
#'
#' @keywords datasets
#'
#' @source  PJ Bickel, EA Hammel, and JW O'Connell. Science (1975)
#' @examples
#' data(admissions)
#' admissions
"admissions"
