#' Adult male heights in feet with outliers
#' 
#' This dataset was randomly generated with a normal distribution (average: 5 feet 9 inches, standard deviation: 3 inches). One value was changed to be mistakenly reported in centimeters rather than feet.
#'
#'
#' @docType data
#'
#' @usage data(outlier_example)
#'
#' @format An object of class \code{"numeric"}. 
#'
#' @keywords datasets
#'
#'
#'
#' @examples
#' data(outlier_example)
#' mean(outlier_example)
#' median(outlier_example)
"outlier_example"