#' Self-reported Heights in Inches
#' 
#' Self-reported heights and sex. The heights were converted to inches from the original data included in \code{\link{reported_heights}}.
#' 
#'\itemize{
#'  \item sex. A factor with the self-reported sex. 
#'  \item height. A numeric vector with self-reported heights in inches. 
#' }
#'
#'
#' @seealso
#' \code{\link{reported_heights}} for the original data source.
#' 
#' @docType data
#'
#' @usage heights
#'
#' @format An object of class \code{"data.frame"}. 
#'
#' @keywords datasets
#'
#'
#'
#' @examples
#' head(heights)
"heights"
