#' Gender bias in research funding in the Netherlands
#' 
#' Table S1 from paper title "Gender contributes to personal research funding success in The Netherlands"
#'
#'
#' \itemize{
#'   \item discipline. Research area discipline.
#'   \item applications_total. Total applications.
#'   \item applications_men. Total applications by men.
#'   \item applications_women. Total applications by women.
#'   \item awards_total. Total awards.
#'   \item awards_men. Total awards received by men.
#'   \item awards_women. Total awards received by women.
#'   \item success_rates_total. Overall success rate.
#'   \item success_rates_men. Success rate for men.
#'   \item success_rates_women. Success rate for women.
#' }
#' 
#' @docType data
#'
#' @usage research_funding_rates
#'
#' @format An object of class \code{"data.frame"}. 
#'
#' @keywords datasets
#'
#' @references van der Lee R, Ellemers N. Gender contributes to personal research funding success in The Netherlands. Proc Natl Acad Sci U S A. 2015 Oct 6;112(40):12349-53. doi: 10.1073/pnas.1510159112. Epub 2015 Sep 21. PMID: 26392544; PMCID: PMC4603485.
#' 
#' @aliases raw_data_research_funding_rates
#' 
#' @examples

#' research_funding_rates
#' # The raw data for this table is available from
#' invisible(raw_data_research_funding_rates)
#' 
"research_funding_rates"
