#' Self-reported Heights 
#' 
#' Students were asked to report their height (in inches) and sex in an online form. 
#' This table includes the results from four courses.
#'
#'\itemize{
#'  \item time_stamp. Time and date of the entry.
#'  \item sex. Sex of the student.
#'  \item height. Height as reported by student by filling in a text free box. 
#' }
#'
#'
#' @docType data
#'
#' @usage data(reported_heights)
#'
#' @format An object of class \code{"data.frame"}. 
#'
#' @keywords datasets
#'
#'
#'
#' @examples
#' data(reported_heights)
#' head(reported_heights)
"reported_heights"
