#' Count data with some missing values
#' 
#' This dataset was randomly generated.
#'
#'
#' @docType data
#'
#' @usage data(na_example)
#'
#' @format An object of class \code{"integer"}. 
#'
#' @keywords datasets
#'
#'
#'
#' @examples
#' data(na_example)
#' print(sum(is.na(na_example)))
"na_example"